/**
 * Copyright (c) Codice Foundation
 * 
 * This is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser
 * General Public License as published by the Free Software Foundation, either version 3 of the
 * License, or any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details. A copy of the GNU Lesser General Public License
 * is distributed along with this program and can be found at
 * <http://www.gnu.org/licenses/lgpl.html>.
 * 
 **/
package ddf.content.operation;

/**
 * Marker interface to differentiate {@link Request}s from {@link Response}s.
 * 
 * @author michael.menousek@lmco.com
 * 
 */
public interface Request extends Operation {
    /** The message header specifying the operation, i.e., create, read, update, delete */
    public static final String OPERATION = "operation";

    /** The message header specifying the directive, i.e., STORE, PROCESS, STORE_AND_PROCESS */
    public static final String DIRECTIVE = "directive";

    /**
     * The message header specifying the content URI, used when content to be stored/processed is
     * not in the message itself but located elsewhere.
     */
    public static final String CONTENT_URI = "contentUri";

    public enum Directive {
        STORE, PROCESS, STORE_AND_PROCESS
    }
}
